@@ -1,11 +1,13 @@
+import contextlib
 import io
 import os
-import sys
+
+from .parser_types import Location
 from .token import Token
 from .gherkin_line import GherkinLine
 
 
-class TokenScanner(object):
+class TokenScanner:
     """
     The scanner reads a gherkin doc (typically read from a `.feature` file) and creates a token for
     each line.
@@ -17,28 +19,20 @@ class TokenScanner(object):
     :file:`gherkin-languages.json`.
     """
 
-    def __init__(self, path_or_str):
+    def __init__(self, path_or_str: str) -> None:
         if os.path.exists(path_or_str):
-            self.io = io.open(path_or_str, 'r', encoding='utf8')
+            self.io = open(path_or_str, encoding="utf8")
         else:
-            if sys.version_info < (3, 0):
-                if isinstance(path_or_str, str):
-                    self.io = io.StringIO(unicode(path_or_str, encoding='utf8'))
-                else:
-                    self.io = io.StringIO(path_or_str)
-            else:
-                self.io = io.StringIO(path_or_str)
+            self.io = io.StringIO(path_or_str)
         self.line_number = 0
 
-    def read(self):
+    def read(self) -> Token:
         self.line_number += 1
-        location = {'line': self.line_number}
+        location: Location = {"line": self.line_number}
         line = self.io.readline()
         return Token((GherkinLine(line, self.line_number) if line else line), location)
 
-    def __del__(self):
+    def __del__(self) -> None:
         # close file descriptor if it's still open
-        try:
+        with contextlib.suppress(AttributeError):
             self.io.close()
-        except AttributeError:
-            pass
